@@ -1,26 +1,27 @@
 from ._spacy_lang import SpacyLanguage
 from ._fasttext_lang import FasttextLanguage
 from ._countvector_lang import CountVectorLanguage
+from ._tfidf_lang import TFIDFVectorLanguage
 from ._bpemblang import BytePairLanguage
 from ._gensim_lang import GensimLanguage
-from ._convert_lang import ConveRTLanguage
 
 from whatlies.error import NotInstalled
 
-try:
-    from ._tfhub_lang import TFHubLanguage
-except ModuleNotFoundError as e:
-    TFHubLanguage = NotInstalled("TFHubLanguage", "tfhub")
 
 try:
+    from ._tfhub_lang import TFHubLanguage
+    from ._convert_lang import ConveRTLanguage
     from ._sentence_encode_lang import UniversalSentenceLanguage
 except ModuleNotFoundError as e:
+    TFHubLanguage = NotInstalled("TFHubLanguage", "tfhub")
+    ConveRTLanguage = NotInstalled("ConveRTLanguage", "tfhub")
     UniversalSentenceLanguage = NotInstalled("UniversalSentenceLanguage", "tfhub")
 
 try:
-    from ._hftransformers_lang import HFTransformersLanguage
+    from ._hftransformers_lang import HFTransformersLanguage, LaBSELanguage
 except ModuleNotFoundError as e:
     HFTransformersLanguage = NotInstalled("HFTransformersLanguage", "transformers")
+    LaBSELanguage = NotInstalled("LaBSELanguage", "transformers")
 
 try:
     from ._sense2vec_lang import Sense2VecLanguage
@@ -38,10 +39,13 @@ __all__ = [
     "Sense2VecLanguage",
     "FasttextLanguage",
     "CountVectorLanguage",
+    "TFIDFVectorLanguage",
     "BytePairLanguage",
     "GensimLanguage",
     "ConveRTLanguage",
     "TFHubLanguage",
     "HFTransformersLanguage",
     "UniversalSentenceLanguage",
+    "SentenceTFMLanguage",
+    "LaBSELanguage",
 ]
